OLIMEX H407 board
=================

This board definition supports the OLIMEX H407 board:
https://www.olimex.com/Products/ARM/ST/STM32-H407/

A REPL is available at the U3BOOT connector with 115200 baud and on the
micro USB socket.

What works
----------

* REPL
* UART
* SD-Card
* Timer
* GPIOs
* USB device on the mini USB socket
